@@ -9,7 +9,8 @@ import sys
 # logger formating
 BRIEF_FORMAT = "%(levelname)s %(asctime)s - %(name)s: %(message)s"
 VERBOSE_FORMAT = (
-    "%(levelname)s|%(asctime)s|%(name)s|%(filename)s|" "%(funcName)s|%(lineno)d: %(message)s"
+    "%(levelname)s|%(asctime)s|%(name)s|%(filename)s|"
+    "%(funcName)s|%(lineno)d: %(message)s"
 )
 FORMAT_TO_USE = VERBOSE_FORMAT
 
