@@ -6,8 +6,10 @@ from tabulate import tabulate
 
 from .core import TestPackage
 
+VALID_OUTPUTS = ["rst", "github"]
 
-def gen_report(testers: List[TestPackage]) -> Any:
+
+def gen_report(testers: List[TestPackage], output_type: str = "rst") -> Any:
     """Generate a rST report.
 
     Parameters
@@ -15,11 +17,17 @@ def gen_report(testers: List[TestPackage]) -> Any:
     testers : list
         A list of ``TestPackage`` objects.
 
+    output_type : str
+        A valid output type of ``rst`` or ``github``
+
     Returns
     -------
     Any
         The report.
     """
+    if output_type not in VALID_OUTPUTS:
+        raise ValueError(f"Invalid output_type provided: {output_type}")
+
     headers = ["Environment", "Passing tests", "Upgraded packages", "Package version"]
     rows: List[List] = []
     for env in testers:
@@ -27,4 +35,4 @@ def gen_report(testers: List[TestPackage]) -> Any:
         for pkg in upgraded:
             rows.append([env.envname, env.status, pkg["name"], pkg["version"]])
 
-    return tabulate(rows, headers=headers, tablefmt="rst")
+    return tabulate(rows, headers=headers, tablefmt=output_type)
